==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/EditModeSelector.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/EditModeSelector", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/drop-down', 'frontend-js-react-web$react', '../actions/togglePermission', '../selectors/selectCanSwitchEditMode', '../store/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = EditModeSelector;

    var _button = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button"));

    var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _togglePermission = _interopRequireDefault(require("../actions/togglePermission"));

    var _selectCanSwitchEditMode = _interopRequireDefault(require("../selectors/selectCanSwitchEditMode"));

    var _index = require("../store/index");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var EDIT_MODES = {
      contentEdition: Liferay.Language.get('content-edition'),
      pageDesign: Liferay.Language.get('page-design')
    };

    function EditModeSelector() {
      var canSwitchEditMode = (0, _index.useSelector)(_selectCanSwitchEditMode["default"]);
      var dispatch = (0, _index.useDispatch)();

      var _useState = (0, _react.useState)(false),
          _useState2 = _slicedToArray(_useState, 2),
          active = _useState2[0],
          setActive = _useState2[1];

      var _useState3 = (0, _react.useState)(canSwitchEditMode ? EDIT_MODES.pageDesign : EDIT_MODES.contentEdition),
          _useState4 = _slicedToArray(_useState3, 2),
          editMode = _useState4[0],
          setEditMode = _useState4[1];

      return _react["default"].createElement(_dropDown["default"], {
        active: active,
        alignmentPosition: _dropDown.Align.BottomLeft,
        className: "mr-3",
        onActiveChange: setActive,
        trigger: _react["default"].createElement(_button["default"], {
          className: "form-control-select page-editor__edit-mode-selector text-left",
          disabled: !canSwitchEditMode,
          displayType: "secondary",
          small: true,
          type: "button"
        }, _react["default"].createElement("span", null, editMode))
      }, _react["default"].createElement(_dropDown["default"].ItemList, null, _react["default"].createElement(_dropDown["default"].Item, {
        onClick: function onClick() {
          setActive(false);
          setEditMode(EDIT_MODES.pageDesign);
          dispatch((0, _togglePermission["default"])('UPDATE', true));
        }
      }, EDIT_MODES.pageDesign), _react["default"].createElement(_dropDown["default"].Item, {
        onClick: function onClick() {
          setActive(false);
          setEditMode(EDIT_MODES.contentEdition);
          dispatch((0, _togglePermission["default"])('UPDATE', false));
        }
      }, EDIT_MODES.contentEdition)));
    }
    //# sourceMappingURL=EditModeSelector.js.map
  }
});
//# sourceMappingURL=EditModeSelector.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/EditModeSelector.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/EditModeSelector", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/drop-down', 'frontend-js-react-web$react', '../actions/togglePermission', '../selectors/selectCanSwitchEditMode', '../store/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = EditModeSelector;

    var _button = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button"));

    var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _togglePermission = _interopRequireDefault(require("../actions/togglePermission"));

    var _selectCanSwitchEditMode = _interopRequireDefault(require("../selectors/selectCanSwitchEditMode"));

    var _index = require("../store/index");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var EDIT_MODES = {
      contentEditing: Liferay.Language.get('content-editing'),
      pageDesign: Liferay.Language.get('page-design')
    };

    function EditModeSelector() {
      var canSwitchEditMode = (0, _index.useSelector)(_selectCanSwitchEditMode.default);
      var dispatch = (0, _index.useDispatch)();

      var _useState = (0, _react.useState)(false),
          _useState2 = _slicedToArray(_useState, 2),
          active = _useState2[0],
          setActive = _useState2[1];

      var _useState3 = (0, _react.useState)(canSwitchEditMode ? EDIT_MODES.pageDesign : EDIT_MODES.contentEditing),
          _useState4 = _slicedToArray(_useState3, 2),
          editMode = _useState4[0],
          setEditMode = _useState4[1];

      return (/*#__PURE__*/_react.default.createElement(_dropDown.default, {
          active: active,
          alignmentPosition: _dropDown.Align.BottomLeft,
          className: "mr-3",
          onActiveChange: setActive,
          trigger: /*#__PURE__*/_react.default.createElement(_button.default, {
            className: "form-control-select page-editor__edit-mode-selector text-left",
            disabled: !canSwitchEditMode,
            displayType: "secondary",
            small: true,
            type: "button"
          }, /*#__PURE__*/_react.default.createElement("span", null, editMode))
        }, /*#__PURE__*/_react.default.createElement(_dropDown.default.ItemList, null, /*#__PURE__*/_react.default.createElement(_dropDown.default.Item, {
          onClick: function onClick() {
            setActive(false);
            setEditMode(EDIT_MODES.pageDesign);
            dispatch((0, _togglePermission.default)('UPDATE', true));
          }
        }, EDIT_MODES.pageDesign), /*#__PURE__*/_react.default.createElement(_dropDown.default.Item, {
          onClick: function onClick() {
            setActive(false);
            setEditMode(EDIT_MODES.contentEditing);
            dispatch((0, _togglePermission.default)('UPDATE', false));
          }
        }, EDIT_MODES.contentEditing)))
      );
    }
    //# sourceMappingURL=EditModeSelector.js.map
  }
});
//# sourceMappingURL=EditModeSelector.js.map
